(* $Id: test_bluemap.ml,v 1.5 2014/02/27 16:36:36 fclement Exp $ *)

open Ppm;;
open Pixmap;;
open Graphics;;

(* Open the graphics window and clear it to black. *)
let open_black_graphics sz_x sz_y =
 open_graph (Printf.sprintf " %dx%d" sz_x sz_y);
 set_color black; fill_rect 0 0 sz_x sz_y;;

(* To animate the test. *)
let wait () =
 print_string "\nPress return to continue"; flush stdout;
 let _ = input_line stdin in
 ();;

let print_and_wait s =
 print_string s; print_newline (); wait ();;

(* To load and save in the proper directory. *)
let load_ppm_file s = load_ppm (Filename.concat "ppms" s);;
let save_ppm_file s ppm = save_ppm (Filename.concat "ppms" s) ppm;;
let save_bitmap_file s ppm = save_bitmap (Filename.concat "ppms" s) ppm;;
let load_bitmap = load_ppm_file;;

open_black_graphics 1200 600;;

(* Load and draw a reference image. *)
let fumi_pixmap = load_ppm_file "fumicaml.ppm";;
draw_pixmap fumi_pixmap 0 0;
print_string "FumiCaml loaded and drawn."; print_newline ();;

let pixmap_dimensions pxm =
  let nl = Array.length pxm in
  if nl = 0 then 0, 0 else
  let nc = Array.length pxm.(0) in
  nl, nc;;

let fumi_width, fumi_height = pixmap_dimensions fumi_pixmap;;

let fumi_bluemap = bluemap_of_blue_channel fumi_pixmap
and fumi_redmap = bluemap_of_red_channel fumi_pixmap
and fumi_greenmap = bluemap_of_green_channel fumi_pixmap;;

let red_fumi_map = red_pixmap_of_bluemap fumi_redmap;;
let green_fumi_map = green_pixmap_of_bluemap fumi_greenmap;;
let blue_fumi_map = blue_pixmap_of_bluemap fumi_bluemap;;

draw_pixmap red_fumi_map 300 10;;
draw_pixmap green_fumi_map 300 210;;
draw_pixmap blue_fumi_map 300 410;;

draw_pixmap (pixmap_of_rgb_bluemaps fumi_redmap fumi_greenmap fumi_bluemap) 10 210;;

let fumi_huemap = bluemap_of_hue_channel fumi_pixmap
and fumi_satmap = bluemap_of_saturation_channel fumi_pixmap
and fumi_brimap = bluemap_of_brightness_channel fumi_pixmap;;

draw_pixmap (gray_pixmap_of_bluemap fumi_redmap) 600 10;;
draw_pixmap (gray_pixmap_of_bluemap fumi_greenmap) 600 210;;
draw_pixmap (gray_pixmap_of_bluemap fumi_bluemap) 600 410;;

draw_pixmap (gray_pixmap_of_bluemap fumi_huemap) 900 10;;
draw_pixmap (gray_pixmap_of_bluemap fumi_satmap) 900 210;;
draw_pixmap (gray_pixmap_of_bluemap fumi_brimap) 900 410;;

wait ();;
