(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: uhistory_spec.mli,v 1.11 2014/05/06 12:56:17 fclement Exp $ *)

open Uhistory_types;;

module type CONFIGURATION =
sig
  type t;;
  
  val print : t Format_printer.printer;;
  
  val cold_set : unit -> unit;;
  val warm_set : t -> unit;;
  val get : unit -> t;;
end
;;

module type STATE =
sig
  type t;;
  
  val same : t -> t -> bool;;
  val print : t Format_printer.printer;;
  
  val init : unit -> t;;
  val final : t -> unit;;
end
;;

module type HISTORY =
sig
  type config;;
  type state;;
  
  type t = (config, state) Uhistory_types.t;;
  
  val make_history_step : state_number -> state -> t -> t;;
  
  val head_state : t -> state;;
  val head_state_number : t -> state_number;;
  
  val same_head_state : t -> t -> bool;;
  
  val print : t Format_printer.printer;;
  val print_head_h_state : t Format_printer.printer;;
  
  val initialization : unit -> t;;
  val finalization : t -> unit;;
end
;;

module type MAKER =
  functor (Config : CONFIGURATION) ->
  functor (St : STATE) ->
  HISTORY with type state = St.t
;;
