(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: display_types.mli,v 1.26 2014/07/16 21:46:59 fclement Exp $ *)

open Refinement_types;;

type length = Upervasives.length
and width = length
and height = length
and size = width * height
and tangential = length
and normal = length
and polar_size = tangential * normal
;;

type color = Colors.t;;

type font_name = string;;

(** {6 Setting the display window} *)

type aspect =
  | Portrait
  | Landscape
;;
(** Aspect ratio of the parameter. *)

type direction =
  | Horizontal_dir
  | Vertical_dir
;;
(** Direction of the current length. *)

type comps_direction =
  | Horizontal_comps_dir
  | Vertical_comps_dir
;;
(** Direction of the components. *)

type image_size = size
and font_size = size
and display_image_size = size
and window_size = size
and sub_window_size = window_size
and min_window_size = window_size
and max_window_size = window_size
;;

type scaling_factor = Upositive_rational.t;;
type scaling = Unatural.t -> Unatural.t;;

type sub_window_sizes =
  {
   title_sub_window_height : length;
   legend_sub_window_polar_size : polar_size;
   colorbar_size : sub_window_size;
   colorbar_sub_window_tangential : length;
   colormap_sub_window_tangential : length;
   pixmap_sub_window_size : sub_window_size;
   quantity_sub_window_size : sub_window_size;
  }
;;

type graphics_elements =
  {
   comps_direction : comps_direction;
   scaling_factor : scaling_factor;
   display_image_size : display_image_size;
   window_size : window_size;
   sub_window_sizes : sub_window_sizes;
  }
;;

(** {6 Quantity} *)

type quantity =
  | Param
  | Grad
;;

type 'a pixmap_iter =
  (zone_number -> 'a sub_parameter -> unit) -> 'a partition -> unit
and 'a colormap = 'a -> color
;;

type pixmap = Generic_image.pixmap
and lower_left_corner = point
;;

type print_pixmap = Format.formatter -> unit
and 'a alter_pixmap = 'a pixmap_iter -> 'a colormap -> 'a partition -> unit
and draw_pixmap = unit -> unit
;;
